## PromptLab

Username
Password
User
Auth Token
Logout

# PromptLab

Select columns to display ▼

| Experiment ID | Completion Model | Embedding Model | Prompt Template | Prompt Template Version | Dataset | Dataset Version | System Prompt | User Prompt | User ID | Created At
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---

Experiment ID | Dataset Record ID | Completion | Completion Tokens | Prompt Tokens | Latency (ms) | ragas-SemanticSimilarity | ragas-RougeScore
--- | --- | --- | --- | --- | --- | --- | ---

# Prompt Templates

Name | Description | Version | System Prompt | User Prompt | Deployment Time | Is Deployed | User ID | Created At
--- | --- | --- | --- | --- | --- | --- | --- | ---

# Assets

Asset management content will go here.

# Datasets

Name | Description | Version | File Path | User ID | Created At
--- | --- | --- | --- | --- | ---

## Your Auth Token